@@ -49,11 +49,12 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
     if (missing(reference)) {
         arguments <- list(l=l, tolerance=tolerance);
 
-        if (.isArgument("minFrequency", optArgs)) {
-            arguments$minFrequency <- optArgs$minFrequency;
-            optArgs <- .removeArguments("minFrequency", optArgs);
-        } 
-
+        for (i in c("method", "minFrequency")) {
+            if (.isArgument(i, optArgs)) {
+                arguments[[i]] <- optArgs[[i]];
+                optArgs <- .removeArguments(i, optArgs);
+            }
+        }
         reference <- do.call(referencePeaks, arguments);
     }
 
@@ -71,7 +72,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
             if (.isArgument(i, optArgs)) {
                 plotArgs[[i]] <- optArgs[[i]];
                 optArgs <- .removeArguments(i, optArgs);
-             }
+            }
         }
     }
 
@@ -99,7 +100,8 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
  
     ## run peak binning and use relaxed grouper which choose the highest test
     ## sample peaks
-    binnedMass <- .binPeaks(mass, intensities, samples, tolerance,
+    binnedMass <- .binPeaks(mass=mass, intensities=intensities,
+                            samples=samples, tolerance=tolerance,
                             grouper=.grouperRelaxedHighestAtReference);
 
     ## group mass/intensities by sample ids
