@@ -26,35 +26,36 @@ setMethod(f=".findLocalMaxima",
         return(matrix(ncol=2, dimnames=list(list(), list("mass", "intensity"))));
     }
 
-    if (halfWindowSize<1) {
-        stop(sQuote("halfWindowSize"), "=", halfWindowSize, " is too small!");
-    }
-
-    ## based on a posting of Brian Ripley on r-help mailinglist
-    ## https://stat.ethz.ch/pipermail/r-help/2001-January/010704.html
-    windowSize <- 2*halfWindowSize+1;
-
-    if (windowSize >= length(object)) {
-        stop(sQuote("halfWindowSize"), " is too large! ",
-             "(window size (", windowSize, ") >= number of ",
-             " mass/intensity values (", length(object), "))");
-    }
-
-    windows <- embed(object@intensity, windowSize);
-
-    localMaxima <- max.col(windows, "first") == halfWindowSize+1
-    
-    localMaxima <- c(rep(FALSE, halfWindowSize), localMaxima, 
-                     rep(FALSE, halfWindowSize));
+    localMaxima <- .localMaxima(object@intensity, halfWindowSize=halfWindowSize)
 
     m <- cbind(object@mass, object@intensity)[localMaxima,];
     
-    if (!is.matrix(m)) {
-        m <- t(as.matrix(m));
-    }
-
     colnames(m) <- c("mass", "intensity");
 
     return(m);
 });
 
+setMethod(f=".findLocalMaximaLogical",
+    signature=signature(object="MassSpectrum"),
+    definition=function(object, 
+                        halfWindowSize=20) {
+
+    if (.isEmptyWarning(object)) {
+        return(logical());
+    }
+
+    if (halfWindowSize<1) {
+        stop(sQuote("halfWindowSize"), "=", halfWindowSize, " is too small!");
+    }
+
+    if (halfWindowSize*2+1 >= length(object)) {
+        stop(sQuote("halfWindowSize"), " is too large! ",
+             "(window size (", halfWindowSize*2+1, ") >= number of ",
+             " intensity values (", length(object), "))");
+    }
+
+    localMaxima <- .localMaxima(object@intensity, halfWindowSize=halfWindowSize)
+
+    return(localMaxima)
+});
+
