@@ -22,8 +22,8 @@
     } 
 
     areFunctions <- length(x) > 0 &&
-                    all( unlist(sapply(x, function(e) {
-                                return(is.function(e))})) );
+                    all(.unlist(vapply(x, function(e) {
+                                return(is.function(e))}, logical(1))) );
     return(areFunctions);
 }
 
